@@ -438,11 +438,12 @@ class CookieUserSetter(AuthKitUserSetter, AuthTKTMiddleware):
         return cookies
         
     def logout_user_cookie(self, environ):
-        environ[self.session_middleware]['authkit.cookie.user'] = None
-        del environ[self.session_middleware]['authkit.cookie.user']
-        environ[self.session_middleware].save()
+        if self.nouserincookie:
+            environ[self.session_middleware]['authkit.cookie.user'] = None
+            del environ[self.session_middleware]['authkit.cookie.user']
+            environ[self.session_middleware].save()
         domain = self.cookie_params.get('domain')
-        path = '/'
+        path = self.cookie_params.get('path', '/')
         if not domain:
             cookies = [('Set-Cookie', '%s=""; Path=%s' % (self.cookie_name, 
                                                           path))]
